@@ -9,7 +9,7 @@ Types::Core - Core types defined as tests and literals (ease of use)
 
 =head1 VERSION
 
-Version "0.2.1";
+Version "0.2.2";
 
 =cut
 
@@ -19,9 +19,11 @@ Version "0.2.1";
   use strict;
   use warnings;
   use mem;
-  our $VERSION='0.2.1';
+  our $VERSION='0.2.2';
   use constant Self => __PACKAGE__;
 
+# 0.2.2   - fixed prototype of isnum, tighted up interface and documented it
+#         - fix some test suit failures under older (<5.12) perls
 # 0.2.1   - re-add 'type' as OK synonym for 'typ' (both in EXPORT_OK)
 # 0.2.0   - Allow isnum to take inferred $_ as param.
 # 0.1.10  - Added Cmp function for nested data structs
@@ -433,7 +435,7 @@ type of error in dynamically allocated variables.
 
 S< >
 
-     isnum X;               #return True if X is a number
+     isnum STR              #return <NUM> if it starts at beginning of STR
 
      Cmp [$p1,$p2]          # C<cmp>-like function for nested structures
                             # uses C<$a>, C<$b> as default inputs
@@ -442,6 +444,15 @@ S< >
                             # builtin debug to see where compare fails
 #
 
+C<isnum> checks for a number (int, float, or with exponent) at the 
+beginning of the string passed in.  With no argument uses C<$_>
+as the parameter.  Returns the number with any non-number suffix
+stripped off or C<undef> if no num is found at the beginning
+of the string.  C<isnum> is an optional import that must be included
+via C<@EXPORTS_OK>.  Note: to determine if false, you must use
+C<defined(isnum)> since numeric '0' can be returned and would also
+evaluate to false.
+
 The existence of C<Cmp> is a B<side effect of testing> needs.  To compare
 validity of released functions, it was necessary to recursively 
 compare nested data structures.  To support development, debug
@@ -473,11 +484,18 @@ be compared.
 
 =cut
 
+use constant numRE => qr{^ ( 
+														[-+]? (?: (?: \d* \.? \d+ ) | 
+																			(?: \d+ \.? \d* ) ) 
+																			(?: [eE] [-+]? \d+)? ) }x;
 
-sub isnum(_;$) { local $_ = @_ ? $_[0] : $_;
-  m{^\s* [-+\d.]* [\d.]+ (?:[eE][-+]\d+)? \s* $}x 
+sub isnum(;$) { 
+	local $_ = @_ ? $_[0] : $_;
+	m"@{[numRE]}" && return $1;
+	undef;
 }
 
+
 sub Cmp (;$$$);
 sub Cmp (;$$$) { my $r=0; my $d;
   require P;
